@@ -73,24 +73,17 @@ def load_omas_json(filename, consistency_check=True, imas_version=omas_rcparams[
 
     def base_class(x):
         clsODS = lambda: ODS(imas_version=imas_version, consistency_check=False)
-        clscls = lambda: ODC(imas_version=imas_version, consistency_check=False)
+        clsODC = lambda: ODC(imas_version=imas_version, consistency_check=False)
         try:
             tmp = json_loader(x, clsODS, null_to=numpy.NaN)
         except Exception:
-            tmp = json_loader(x, clscls, null_to=numpy.NaN)
+            tmp = json_loader(x, clsODC, null_to=numpy.NaN)
         return tmp
 
     tmp = json.loads(json_string, object_pairs_hook=lambda x: base_class(x), **kw)
 
     # convert to cls
     tmp.__class__ = cls
-    data = tmp.omas_data
-    tmp.omas_data = OrderedDict()
-    tmp.update(data)
-
-    # we must manually call set_child_locations since the json_loader
-    # routine uses the ODS.setraw method that does not do that for us
-    tmp.set_child_locations()
 
     # perform consistency check
     tmp.consistency_check = consistency_check
@@ -107,6 +100,7 @@ def through_omas_json(ods, method=['function', 'class_method'][1]):
     :return: ods
     """
     filename = omas_testdir(__file__) + '/test.json'
+    ods = copy.deepcopy(ods)  # make a copy to make sure save does not alter entering ODS
     if method == 'function':
         save_omas_json(ods, filename)
         ods1 = load_omas_json(filename)
