@@ -11,17 +11,17 @@ Test script for omas saving/loading data in different formats
 -------
 """
 
-import unittest
 import os
 import numpy
 
 # OMAS imports
 from omas import *
+from omas.omas_utils import *
 from omas.tests.failed_imports import *
 from omas.tests import warning_setup
 
 
-class TestOmasSuite(unittest.TestCase):
+class TestOmasSuite(UnittestCaseOmas):
     def test_omas_pkl(self):
         ods = ODS().sample()
         ods1 = through_omas_pkl(ods)
@@ -55,27 +55,34 @@ class TestOmasSuite(unittest.TestCase):
             raise AssertionError('h5 through difference')
 
     def test_omas_ds(self):
-        ods = ODS().sample()
+        ods = ODS().sample(homogeneous_time=True)
         ods1 = through_omas_ds(ods)
         diff = ods.diff(ods1)
         if diff:
             print('\n'.join(diff))
             raise AssertionError('ds through difference')
 
-    def test_omas_ascii(self):
+    def test_omas_ascii_many(self):
         ods = ODS().sample()
-        for one_or_many_files in ['one', 'many']:
-            ods1 = through_omas_ascii(ods, one_or_many_files=one_or_many_files)
-            diff = ods.diff(ods1)
-            if diff:
-                print('\n'.join(diff))
-                raise AssertionError(f'ascii through difference for {one_or_many_files} file(s)')
+        ods1 = through_omas_ascii(ods, one_or_many_files='many')
+        diff = ods.diff(ods1)
+        if diff:
+            print('\n'.join(diff))
+            raise AssertionError(f'ascii through difference for many files')
+
+    def test_omas_ascii_one(self):
+        ods = ODS().sample()
+        ods1 = through_omas_ascii(ods, one_or_many_files='one')
+        diff = ods.diff(ods1)
+        if diff:
+            print('\n'.join(diff))
+            raise AssertionError(f'ascii through difference for one file')
 
     def test_omas_dx(self):
-        ods = ODS().sample()
-        odx = ods_2_odx(ods)
+        ods = ODS().sample(homogeneous_time=True)
+        odx = ods.to_odx()
         odx1 = through_omas_dx(odx)
-        ods1 = odx_2_ods(odx1)
+        ods1 = odx1.to_ods()
         diff = ods.diff(ods1)
         if diff:
             print('\n'.join(diff))
